funcs

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 28, 2020 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Code generated by go generate; DO NOT EDIT. This file was generated by robots at 2020-11-14 18:49:41.68403 +0000 UTC

Package funcs provides copy functions for specified types.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get(dst, src reflect.Type) func(dst, src unsafe.Pointer)

Get the copy function for the pair of types, if it is not found then nil is returned.

func Set

func Set(dst, src reflect.Type, f func(dst, src unsafe.Pointer))

Set the copy function for the pair of types.

Types

type CopyFuncs

type CopyFuncs struct {
	// contains filtered or unexported fields
}

CopyFuncs is the storage of functions intended for copying data.

func (*CopyFuncs) Get

func (t *CopyFuncs) Get(dst, src reflect.Type) func(dst, src unsafe.Pointer)

Get the copy function for the pair of types, if it is not found then nil is returned.

func (*CopyFuncs) Set

func (t *CopyFuncs) Set(dst, src reflect.Type, f func(dst, src unsafe.Pointer))

Set the copy function for the pair of types.

Jump to