package
Version:
v0.6.0
Opens a new window with list of versions in this module.
Published: Dec 28, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Code generated by go generate; DO NOT EDIT.
This file was generated by robots at
2020-11-14 18:49:41.68403 +0000 UTC
Package funcs provides copy functions for specified types.
Get the copy function for the pair of types, if it is not found then nil is returned.
Set the copy function for the pair of types.
type CopyFuncs struct {
}
CopyFuncs is the storage of functions intended for copying data.
Get the copy function for the pair of types, if it is not found then nil is returned.
Set the copy function for the pair of types.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.