Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
Cache is structs' cache.
type Struct ¶
Struct fields info.
func (Struct) Field ¶
Field returns a struct type's i'th field. It panics if i is not in the range [0, NumField()).
func (Struct) FieldByName ¶
FieldByName returns the struct field with the given name and a boolean indicating if the field was found.
Click to show internal directories.
Click to hide internal directories.